@@ -109,7 +109,7 @@ if ($OPT{'df'} && (!$ValidErr || $OPT{'force'}) ) {
 }
 
 $Obj->_bs('cleanup','Сборка мусора');
-$Obj->Cleanup($ValidErr?1:0);
+#$Obj->Cleanup($ValidErr?1:0);
 $Obj->_be('cleanup');
 
 $Obj->_be('ALL');
